@@ -17,12 +17,11 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * 
+ * $Id: mb_c.cpp 8919 2007-03-19 20:27:18Z luks $
  */
  
 #include <string.h>
 #include <musicbrainz3/query.h>
-#include <musicbrainz3/utils.h>
 #include <musicbrainz3/mb_c.h>
 
 extern "C" {
@@ -215,72 +214,28 @@ MbArtist
 mb_query_get_artist_by_id(MbQuery q, const char *id, MbArtistIncludes inc)
 {
 	Query *query = (Query *)q;
-	try {
-		return (MbArtist)query->getArtistById(id, (ArtistIncludes *)inc);
-	}
-	catch (...) {
-		return NULL;
-	}
-}
-
-MbLabel
-mb_query_get_label_by_id(MbQuery q, const char *id, MbLabelIncludes inc)
-{
-	Query *query = (Query *)q;
-	try {
-		return (MbLabel)query->getLabelById(id, (LabelIncludes *)inc);
-	}
-	catch (...) {
-		return NULL;
-	}
+	return (MbArtist)query->getArtistById(id, (ArtistIncludes *)inc);
 }
 
 MbRelease
 mb_query_get_release_by_id(MbQuery q, const char *id, MbReleaseIncludes inc)
 {
 	Query *query = (Query *)q;
-	try {
-		return (MbRelease)query->getReleaseById(id, (ReleaseIncludes *)inc);
-	}
-	catch (...) {
-		return NULL;
-	}
-}
-
-MbReleaseGroup
-mb_query_get_release_group_by_id(MbQuery q, const char *id, MbReleaseGroupIncludes inc)
-{
-	Query *query = (Query *)q;
-	try {
-		return (MbReleaseGroup)query->getReleaseGroupById(id, (ReleaseGroupIncludes *)inc);
-	}
-	catch (...) {
-		return NULL;
-	}
+	return (MbRelease)query->getReleaseById(id, (ReleaseIncludes *)inc);
 }
 
 MbTrack
 mb_query_get_track_by_id(MbQuery q, const char *id, MbTrackIncludes inc)
 {
 	Query *query = (Query *)q;
-	try {
-		return (MbTrack)query->getTrackById(id, (TrackIncludes *)inc);
-	}
-	catch (...) {
-		return NULL;
-	}
+	return (MbTrack)query->getTrackById(id, (TrackIncludes *)inc);
 }
 
 MbUser
 mb_query_get_user_by_name(MbQuery q, const char *name)
 {
 	Query *query = (Query *)q;
-	try {
-		return (MbUser)query->getUserByName(name);
-	}
-	catch (...) {
-		return NULL;
-	}
+	return (MbUser)query->getUserByName(name);
 }
 
 void
@@ -292,143 +247,55 @@ mb_result_list_free(MbResultList list)
 int
 mb_result_list_get_size(MbResultList list)
 {
-	try {
-		return ((ResultList *)list)->size();
-	}
-	catch (...) {
-		return 0;
-	}
+    return ((ResultList *)list)->size();
 }
 
 int
 mb_result_list_get_score(MbResultList list, int index)
 {
-	try {
-		return (*((ResultList *)list))[index]->getScore();
-	}
-	catch (...) {
-		return 0;
-	}
+    return (*((ResultList *)list))[index]->getScore();
 }
 
 MbArtist
 mb_result_list_get_artist(MbResultList list, int index)
 {
-	try {
-		return (MbArtist)(*((ArtistResultList *)list))[index]->getArtist();
-	}
-	catch (...) {
-		return NULL;
-	}
-}
-
-MbLabel
-mb_result_list_get_label(MbResultList list, int index)
-{
-	try {
-		return (MbLabel)(*((LabelResultList *)list))[index]->getLabel();
-	}
-	catch (...) {
-		return NULL;
-	}
+    return (MbArtist)(*((ArtistResultList *)list))[index]->getArtist();
 }
 
 MbRelease
 mb_result_list_get_release(MbResultList list, int index)
 {
-	try {
-		return (*((ReleaseResultList *)list))[index]->getRelease();
-	}
-	catch (...) {
-		return NULL;
-	}
-}
-
-MbReleaseGroup
-mb_result_list_get_release_group(MbResultList list, int index)
-{
-	try {
-		return (*((ReleaseGroupResultList *)list))[index]->getReleaseGroup();
-	}
-	catch (...) {
-		return NULL;
-	}
+    return (*((ReleaseResultList *)list))[index]->getRelease();
 }
 
 MbTrack
 mb_result_list_get_track(MbResultList list, int index)
 {
-	try {
-		return (*((TrackResultList *)list))[index]->getTrack();
-	}
-	catch (...) {
-		return NULL;
-	}
+    return (*((TrackResultList *)list))[index]->getTrack();
 }
 
 MB_API MbResultList
 mb_query_get_artists(MbQuery q, MbArtistFilter flt)
 {
 	Query *query = (Query *)q;
-	try {
-		ArtistResultList *results = new ArtistResultList(query->getArtists((ArtistFilter *)flt));
-    	return (MbResultList)results;
-	}
-	catch (...) {
-		return NULL;
-	}
-}
-
-MB_API MbResultList
-mb_query_get_labels(MbQuery q, MbLabelFilter flt)
-{
-	Query *query = (Query *)q;
-	try {
-		LabelResultList *results = new LabelResultList(query->getLabels((LabelFilter *)flt));
-    	return (MbResultList)results;
-	}
-	catch (...) {
-		return NULL;
-	}
+	ArtistResultList *results = new ArtistResultList(query->getArtists((ArtistFilter *)flt));
+    return (MbResultList)results;
 }
 
 MB_API MbResultList
 mb_query_get_releases(MbQuery q, MbReleaseFilter flt)
 {
 	Query *query = (Query *)q;
-	try {
-		ReleaseResultList *results = new ReleaseResultList(query->getReleases((ReleaseFilter *)flt));
-	    return (MbResultList)results;
-	}
-	catch (...) {
-		return NULL;
-	}
-}
-
-MB_API MbResultList
-mb_query_get_release_groups(MbQuery q, MbReleaseGroupFilter flt)
-{
-	Query *query = (Query *)q;
-	try {
-		ReleaseGroupResultList *results = new ReleaseGroupResultList(query->getReleaseGroups((ReleaseGroupFilter *)flt));
-	    return (MbResultList)results;
-	}
-	catch (...) {
-		return NULL;
-	}
+	ReleaseResultList *results = new ReleaseResultList(query->getReleases((ReleaseFilter *)flt));
+    return (MbResultList)results;
 }
 
 MB_API MbResultList
 mb_query_get_tracks(MbQuery q, MbTrackFilter flt)
 {
 	Query *query = (Query *)q;
-	try {
-		TrackResultList *results = new TrackResultList(query->getTracks((TrackFilter *)flt));
-	    return (MbResultList)results;
-	}
-	catch (...) {
-		return NULL;
-	}
+	TrackResultList *results = new TrackResultList(query->getTracks((TrackFilter *)flt));
+    return (MbResultList)results;
 }
 
 
@@ -450,25 +317,6 @@ MB_C_OBJ_LIST_GETTER(Artist, artist, Aliases, aliases, Alias, alias, ArtistAlias
 MB_C_OBJ_LIST_GETTER(Artist, artist, Releases, releases, Release, release, Release)
 MB_C_OBJ_LIST_GETTER(Artist, artist, Relations, relations, Relation, relation, Relation)
 
-/* === MusicBrainz::Label === */
-
-MB_C_FREE(Label, label)
-
-MB_C_STR_GETTER(Label, label, Id, id)
-MB_C_STR_GETTER(Label, label, Type, type)
-MB_C_INT_GETTER(Label, label, Code, code)
-MB_C_STR_GETTER(Label, label, Name, name)
-MB_C_STR_GETTER(Label, label, SortName, sortname)
-MB_C_STR_GETTER(Label, label, Disambiguation, disambiguation)
-MB_C_STR_GETTER(Label, label, UniqueName, unique_name)
-MB_C_STR_GETTER(Label, label, BeginDate, begin_date)
-MB_C_STR_GETTER(Label, label, EndDate, end_date)
-MB_C_INT_GETTER(Label, label, ReleasesOffset, releases_offset)
-MB_C_INT_GETTER(Label, label, ReleasesCount, releases_count)
-MB_C_OBJ_LIST_GETTER(Label, label, Aliases, aliases, Alias, alias, LabelAlias)
-MB_C_OBJ_LIST_GETTER(Label, label, Releases, releases, Release, release, Release)
-MB_C_OBJ_LIST_GETTER(Label, label, Relations, relations, Relation, relation, Relation)
-
 /* === MusicBrainz::Release === */
 
 MB_C_FREE(Release, release)
@@ -485,16 +333,6 @@ MB_C_OBJ_LIST_GETTER(Release, release, Discs, discs, Disc, disc, Disc)
 MB_C_OBJ_LIST_GETTER(Release, release, ReleaseEvents, release_events, ReleaseEvent, release_event, ReleaseEvent)
 MB_C_OBJ_LIST_GETTER(Release, release, Relations, relations, Relation, relation, Relation)
 MB_C_STR_LIST_GETTER(Release, release, Types, types, Type, type)
-MB_C_OBJ_GETTER(Release, release, Artist, artist, MbArtist)
-
-/* === MusicBrainz::ReleaseGroup === */
-
-MB_C_FREE(ReleaseGroup, release_group)
-
-MB_C_STR_GETTER(ReleaseGroup, release_group, Id, id)
-MB_C_STR_GETTER(ReleaseGroup, release_group, Title, title)
-MB_C_STR_GETTER(ReleaseGroup, release_group, Type, type)
-MB_C_OBJ_LIST_GETTER(ReleaseGroup, release_group, Releases, releases, Release, release, Release)
 
 /* === MusicBrainz::Track === */
 
@@ -504,7 +342,6 @@ MB_C_STR_GETTER(Track, track, Id, id)
 MB_C_STR_GETTER(Track, track, Title, title)
 MB_C_INT_GETTER(Track, track, Duration, duration)
 MB_C_OBJ_LIST_GETTER(Track, track, Relations, relations, Relation, relation, Relation)
-MB_C_OBJ_GETTER(Track, track, Artist, artist, MbArtist)
 
 /* === MusicBrainz::ArtistAlias === */
 
@@ -512,12 +349,6 @@ MB_C_STR_GETTER(ArtistAlias, artist_alias, Value, value)
 MB_C_STR_GETTER(ArtistAlias, artist_alias, Type, type)
 MB_C_STR_GETTER(ArtistAlias, artist_alias, Script, script)
 
-/* === MusicBrainz::LabelAlias === */
-
-MB_C_STR_GETTER(LabelAlias, label_alias, Value, value)
-MB_C_STR_GETTER(LabelAlias, label_alias, Type, type)
-MB_C_STR_GETTER(LabelAlias, label_alias, Script, script)
-
 /* === MusicBrainz::User === */
 
 MB_C_FREE(User, user)
@@ -536,9 +367,6 @@ MB_C_INCLUDES(ArtistIncludes, artist_includes, artistRelations, artist_relations
 MB_C_INCLUDES(ArtistIncludes, artist_includes, releaseRelations, release_relations)
 MB_C_INCLUDES(ArtistIncludes, artist_includes, trackRelations, track_relations)
 MB_C_INCLUDES(ArtistIncludes, artist_includes, urlRelations, url_relations)
-MB_C_INCLUDES(ArtistIncludes, artist_includes, releaseEvents, release_events)
-MB_C_INCLUDES(ArtistIncludes, artist_includes, ratings, ratings)
-MB_C_INCLUDES(ArtistIncludes, artist_includes, tags, tags)
 
 MbArtistIncludes
 mb_artist_includes_releases(MbArtistIncludes o, const char *str) 
@@ -554,19 +382,6 @@ mb_artist_includes_va_releases(MbArtistIncludes o, const char *str)
 	return o; 
 } 
 
-/* === MusicBrainz::ArtistIncludes === */
-
-MB_C_NEW_NOARGS(LabelIncludes, label_includes)
-MB_C_FREE(LabelIncludes, label_includes)
-
-MB_C_INCLUDES(LabelIncludes, label_includes, aliases, aliases)
-MB_C_INCLUDES(LabelIncludes, label_includes, labelRelations, label_relations)
-MB_C_INCLUDES(LabelIncludes, label_includes, releaseRelations, release_relations)
-MB_C_INCLUDES(LabelIncludes, label_includes, trackRelations, track_relations)
-MB_C_INCLUDES(LabelIncludes, label_includes, urlRelations, url_relations)
-MB_C_INCLUDES(LabelIncludes, label_includes, ratings, ratings)
-MB_C_INCLUDES(LabelIncludes, label_includes, tags, tags)
-
 /* === MusicBrainz::ReleaseIncludes === */
 
 MB_C_NEW_NOARGS(ReleaseIncludes, release_includes)
@@ -581,8 +396,6 @@ MB_C_INCLUDES(ReleaseIncludes, release_includes, artistRelations, artist_relatio
 MB_C_INCLUDES(ReleaseIncludes, release_includes, releaseRelations, release_relations)
 MB_C_INCLUDES(ReleaseIncludes, release_includes, trackRelations, track_relations)
 MB_C_INCLUDES(ReleaseIncludes, release_includes, urlRelations, url_relations)
-MB_C_INCLUDES(ReleaseIncludes, release_includes, ratings, ratings)
-MB_C_INCLUDES(ReleaseIncludes, release_includes, tags, tags)
 
 /* === MusicBrainz::TrackIncludes === */
 
@@ -596,8 +409,6 @@ MB_C_INCLUDES(TrackIncludes, track_includes, artistRelations, artist_relations)
 MB_C_INCLUDES(TrackIncludes, track_includes, releaseRelations, release_relations)
 MB_C_INCLUDES(TrackIncludes, track_includes, trackRelations, track_relations)
 MB_C_INCLUDES(TrackIncludes, track_includes, urlRelations, url_relations)
-MB_C_INCLUDES(TrackIncludes, track_includes, ratings, ratings)
-MB_C_INCLUDES(TrackIncludes, track_includes, tags, tags)
 
 /* === MusicBrainz::ReleaseEvent === */
 
@@ -658,18 +469,8 @@ MB_C_NEW_NOARGS(ArtistFilter, artist_filter)
 MB_C_FREE(ArtistFilter, artist_filter)
 
 MB_C_STR_FILTER(ArtistFilter, artist_filter, name, name)
-MB_C_STR_FILTER(ArtistFilter, artist_filter, query, query)
 MB_C_INT_FILTER(ArtistFilter, artist_filter, limit, limit)
 
-/* === MusicBrainz::LabelFilter === */
-
-MB_C_NEW_NOARGS(LabelFilter, label_filter)
-MB_C_FREE(LabelFilter, label_filter)
-
-MB_C_STR_FILTER(LabelFilter, label_filter, name, name)
-MB_C_STR_FILTER(LabelFilter, label_filter, query, query)
-MB_C_INT_FILTER(LabelFilter, label_filter, limit, limit)
-
 /* === MusicBrainz::ReleaseFilter === */
 
 MB_C_NEW_NOARGS(ReleaseFilter, release_filter)
@@ -680,7 +481,6 @@ MB_C_STR_FILTER(ReleaseFilter, release_filter, discId, disc_id)
 MB_C_STR_FILTER(ReleaseFilter, release_filter, releaseType, release_type)
 MB_C_STR_FILTER(ReleaseFilter, release_filter, artistName, artist_name)
 MB_C_STR_FILTER(ReleaseFilter, release_filter, artistId, artist_id)
-MB_C_STR_FILTER(ReleaseFilter, release_filter, query, query)
 MB_C_INT_FILTER(ReleaseFilter, release_filter, limit, limit)
 
 /* === MusicBrainz::TrackFilter === */
@@ -695,7 +495,6 @@ MB_C_STR_FILTER(TrackFilter, track_filter, artistName, artist_name)
 MB_C_STR_FILTER(TrackFilter, track_filter, artistId, artist_id)
 MB_C_INT_FILTER(TrackFilter, track_filter, duration, duration)
 MB_C_STR_FILTER(TrackFilter, track_filter, puid, puid)
-MB_C_STR_FILTER(TrackFilter, track_filter, query, query)
 MB_C_INT_FILTER(TrackFilter, track_filter, limit, limit)
 
 /* === MusicBrainz::UserFilter === */
@@ -705,22 +504,5 @@ MB_C_FREE(UserFilter, user_filter)
 
 MB_C_STR_FILTER(UserFilter, user_filter, name, name)
 
-/* === Utils === */
-
-void
-mb_extract_fragment(const char *uri, char *fragment, int len)
-{
-  string uri_tmp(uri);
-  string fragment_tmp = extractFragment(uri_tmp);
-  strncpy(fragment, fragment_tmp.c_str(), len);
-}
-
-void
-mb_extract_uuid(const char *uri, char *uuid, int len)
-{
-  string uri_tmp(uri);
-  string uuid_tmp = extractUuid(uri_tmp);
-  strncpy(uuid, uuid_tmp.c_str(), len);
-}
 
 }
