@@ -17,12 +17,13 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * 
+ * $Id: mbxmlparser.cpp 8794 2007-01-18 23:37:36Z luks $
  */
  
 // TODO: support for namespaces and full MMD 
  
 #include <string>
+#include <iostream>
 #include <cctype>
 #include <algorithm>
 #include <cstring>
@@ -49,35 +50,24 @@ public:
 	void addArtistAliasesToList(XMLNode listNode, ArtistAliasList &resultList);
 	void addDiscsToList(XMLNode listNode, DiscList &resultList);
 	void addReleasesToList(XMLNode listNode, ReleaseList &resultList);
-	void addReleaseGroupsToList(XMLNode listNode, ReleaseGroupList &resultList);
 	void addReleaseEventsToList(XMLNode listNode, ReleaseEventList &resultList);
 	void addTracksToList(XMLNode listNode, TrackList &resultList);
 	void addUsersToList(XMLNode listNode, UserList &resultList);
-	void addTagsToList(XMLNode listNode, TagList &resultList);
-	void addLabelAliasesToList(XMLNode listNode, LabelAliasList &resultList);
-	void addIsrcsToList(XMLNode listNode, IsrcList &resultList);
-	void addRating(XMLNode node, Entity *entity);
 
 	template<typename T, typename TL, typename TR>
 	void addResults(XMLNode listNode, TL &resultList, T *(MbXmlParserPrivate::*creator)(XMLNode));
 	
 	void addArtistResults(XMLNode listNode, ArtistResultList &resultList);
-	void addLabelResults(XMLNode listNode, LabelResultList &resultList);
 	void addReleaseResults(XMLNode listNode, ReleaseResultList &resultList);
-	void addReleaseGroupResults(XMLNode listNode, ReleaseGroupResultList &resultList);
 	void addTrackResults(XMLNode listNode, TrackResultList &resultList);
 	
 	Artist *createArtist(XMLNode artistNode);
 	ArtistAlias *createArtistAlias(XMLNode artistAliasNode);
 	Disc *createDisc(XMLNode artistNode);
 	Release *createRelease(XMLNode releaseNode);
-	ReleaseGroup *createReleaseGroup(XMLNode releaseGroupNode);
 	ReleaseEvent *createReleaseEvent(XMLNode releaseNode);
 	Track *createTrack(XMLNode releaseNode);
 	User *createUser(XMLNode releaseNode);
-	Tag *createTag(XMLNode releaseNode);
-	Label *createLabel(XMLNode releaseNode);
-	LabelAlias *createLabelAlias(XMLNode releaseNode);
 
 	DefaultFactory factory;
 };
@@ -86,7 +76,7 @@ static bool
 getBoolAttr(XMLNode node, string name)
 {
 	const char *value = node.getAttribute(name.c_str());
-	return value ? string(value) == string("true") : false;
+	return value ? value == "true" : false;
 }
 
 static int
@@ -155,14 +145,7 @@ getInt(XMLNode node, int def = 0)
 {
 	string text = getText(node);
 	return text.empty() ? def : atoi(text.c_str());
-}
-
-static float
-getFloat(XMLNode node, float def = 0)
-{
-	string text = getText(node);
-	return text.empty() ? def : atof(text.c_str());
-}
+} 
 
 Artist *
 MbXmlParser::MbXmlParserPrivate::createArtist(XMLNode artistNode)
@@ -201,12 +184,6 @@ MbXmlParser::MbXmlParserPrivate::createArtist(XMLNode artistNode)
 		else if (name == "relation-list") {
 			addRelationsToEntity(node, artist);
 		}
-		else if (name == "tag-list") {
-			addTagsToList(node, artist->getTags());
-		}
-		else if (name == "rating") {
-			addRating(node, artist);
-		}
 	}
 	return artist; 
 }
@@ -221,75 +198,6 @@ MbXmlParser::MbXmlParserPrivate::createArtistAlias(XMLNode node)
 	return alias;
 }
 
-Label *
-MbXmlParser::MbXmlParserPrivate::createLabel(XMLNode labelNode)
-{
-	Label *label = factory.newLabel();
-	label->setId(getIdAttr(labelNode, "id", "label"));
-	label->setType(getUriAttr(labelNode, "type"));
-	for (int i = 0; i < labelNode.nChildNode(); i++) {
-		XMLNode node = labelNode.getChildNode(i);
-		string name = node.getName(); 
-		if (name == "name") {
-			label->setName(getText(node));
-		}
-		else if (name == "sort-name") {
-			label->setSortName(getText(node));
-		}
-		else if (name == "disambiguation") {
-			label->setDisambiguation(getText(node));
-		}
-		else if (name == "label-code") {
-			label->setCode(getInt(node));
-		}
-		else if (name == "life-span") {
-			const char *begin = node.getAttribute("begin");
-			const char *end = node.getAttribute("end");
-			if (begin)
-				label->setBeginDate(string(begin));
-			if (end)
-				label->setEndDate(string(end));
-		}
-		else if (name == "alias-list") {
-			addLabelAliasesToList(node, label->getAliases());
-		}
-		else if (name == "release-list") {
-			label->setReleasesOffset(getIntAttr(node, "offset"));
-			label->setReleasesCount(getIntAttr(node, "count"));
-			addReleasesToList(node, label->getReleases());
-		}
-		else if (name == "relation-list") {
-			addRelationsToEntity(node, label);
-		}
-		else if (name == "tag-list") {
-			addTagsToList(node, label->getTags());
-		}
-		else if (name == "rating") {
-			addRating(node, label);
-		}
-	}
-	return label; 
-}
-
-LabelAlias *
-MbXmlParser::MbXmlParserPrivate::createLabelAlias(XMLNode node)
-{
-	LabelAlias *alias = factory.newLabelAlias();
-	alias->setType(getUriAttr(node, "type"));
-	alias->setScript(getTextAttr(node, "script"));
-	alias->setValue(getText(node));
-	return alias;
-}
-
-Tag *
-MbXmlParser::MbXmlParserPrivate::createTag(XMLNode node)
-{
-	Tag *tag = factory.newTag();
-	tag->setCount(getIntAttr(node, "count"));
-	tag->setName(getText(node));
-	return tag;
-}
-
 
 string
 getResourceType(const string &type)
@@ -380,9 +288,6 @@ MbXmlParser::MbXmlParserPrivate::createRelease(XMLNode releaseNode)
 		else if (name == "artist") {
 			release->setArtist(createArtist(node));
 		}
-		else if (name == "release-group") {
-			release->setReleaseGroup(createReleaseGroup(node));
-		}
 		else if (name == "release-event-list") {
 			addReleaseEventsToList(node, release->getReleaseEvents());
 		}
@@ -397,38 +302,10 @@ MbXmlParser::MbXmlParserPrivate::createRelease(XMLNode releaseNode)
 		else if (name == "relation-list") {
 			addRelationsToEntity(node, release);
 		}
-		else if (name == "tag-list") {
-			addTagsToList(node, release->getTags());
-		}
-		else if (name == "rating") {
-			addRating(node, release);
-		}
 	}
 	return release;
 }
 
-ReleaseGroup *
-MbXmlParser::MbXmlParserPrivate::createReleaseGroup(XMLNode releaseGroupNode)
-{
-	ReleaseGroup *releaseGroup = factory.newReleaseGroup();
-	releaseGroup->setId(getIdAttr(releaseGroupNode, "id", "release-group"));
-	releaseGroup->setType(getUriAttr(releaseGroupNode, "type"));
-	for (int i = 0; i < releaseGroupNode.nChildNode(); i++) {
-		XMLNode node = releaseGroupNode.getChildNode(i);
-		string name = node.getName();
-		if (name == "title") {
-			releaseGroup->setTitle(getText(node));
-		}
-		else if (name == "artist") {
-			releaseGroup->setArtist(createArtist(node));
-		}
-		else if (name == "release-list") {
-			addReleasesToList(node, releaseGroup->getReleases());
-		}
-	}
-	return releaseGroup;
-}
-
 Track *
 MbXmlParser::MbXmlParserPrivate::createTrack(XMLNode trackNode)
 {
@@ -454,15 +331,6 @@ MbXmlParser::MbXmlParserPrivate::createTrack(XMLNode trackNode)
 		else if (name == "relation-list") {
 			addRelationsToEntity(node, track);
 		}
-		else if (name == "tag-list") {
-			addTagsToList(node, track->getTags());
-		}
-		else if (name == "isrc-list") {
-			addIsrcsToList(node, track->getIsrcs());
-		}
-		else if (name == "rating") {
-			addRating(node, track);
-		}
 	}
 	return track;
 }
@@ -501,15 +369,6 @@ MbXmlParser::MbXmlParserPrivate::createReleaseEvent(XMLNode releaseEventNode)
 	ReleaseEvent *releaseEvent = factory.newReleaseEvent();
 	releaseEvent->setCountry(getTextAttr(releaseEventNode, "country"));
 	releaseEvent->setDate(getTextAttr(releaseEventNode, "date"));
-	releaseEvent->setCatalogNumber(getTextAttr(releaseEventNode, "catalog-number"));
-	releaseEvent->setBarcode(getTextAttr(releaseEventNode, "barcode"));
-	for (int i = 0; i < releaseEventNode.nChildNode(); i++) {
-		XMLNode node = releaseEventNode.getChildNode(i);
-		string name = node.getName();
-		if (name == "label") {
-			releaseEvent->setLabel(createLabel(node));
-		}
-	}
 	return releaseEvent;
 }
 
@@ -531,24 +390,12 @@ MbXmlParser::MbXmlParserPrivate::addArtistResults(XMLNode listNode, ArtistResult
 	addResults<Artist, ArtistResultList, ArtistResult>(listNode, resultList, &MbXmlParserPrivate::createArtist);
 }
 
-void
-MbXmlParser::MbXmlParserPrivate::addLabelResults(XMLNode listNode, LabelResultList &resultList)
-{
-	addResults<Label, LabelResultList, LabelResult>(listNode, resultList, &MbXmlParserPrivate::createLabel);
-}
-
 void
 MbXmlParser::MbXmlParserPrivate::addReleaseResults(XMLNode listNode, ReleaseResultList &resultList)
 {
 	addResults<Release, ReleaseResultList, ReleaseResult>(listNode, resultList, &MbXmlParserPrivate::createRelease);
 }
 
-void
-MbXmlParser::MbXmlParserPrivate::addReleaseGroupResults(XMLNode listNode, ReleaseGroupResultList &resultList)
-{
-	addResults<ReleaseGroup, ReleaseGroupResultList, ReleaseGroupResult>(listNode, resultList, &MbXmlParserPrivate::createReleaseGroup);
-}
-
 void
 MbXmlParser::MbXmlParserPrivate::addTrackResults(XMLNode listNode, TrackResultList &resultList)
 {
@@ -589,12 +436,6 @@ MbXmlParser::MbXmlParserPrivate::addReleasesToList(XMLNode listNode, ReleaseList
 	addToList<Release, ReleaseList>(listNode, resultList, &MbXmlParserPrivate::createRelease);
 }
 
-void
-MbXmlParser::MbXmlParserPrivate::addReleaseGroupsToList(XMLNode listNode, ReleaseGroupList &resultList)
-{
-	addToList<ReleaseGroup, ReleaseGroupList>(listNode, resultList, &MbXmlParserPrivate::createReleaseGroup);
-}
-
 void
 MbXmlParser::MbXmlParserPrivate::addReleaseEventsToList(XMLNode listNode, ReleaseEventList &resultList)
 {
@@ -613,39 +454,6 @@ MbXmlParser::MbXmlParserPrivate::addUsersToList(XMLNode listNode, UserList &resu
 	addToList<User, UserList>(listNode, resultList, &MbXmlParserPrivate::createUser);
 }
 
-void
-MbXmlParser::MbXmlParserPrivate::addTagsToList(XMLNode listNode, TagList &resultList)
-{
-	addToList<Tag, TagList>(listNode, resultList, &MbXmlParserPrivate::createTag);
-}
-
-void
-MbXmlParser::MbXmlParserPrivate::addIsrcsToList(XMLNode listNode, IsrcList &resultList)
-{
-	for (int i = 0; i < listNode.nChildNode(); i++) {
-		XMLNode node = listNode.getChildNode(i);
-		if (node.getName() == string("isrc")) {
-			string isrc = getTextAttr(node, "id");
-			if (isrc.size()) {
-				resultList.push_back(isrc);
-			}
-		}
-	}
-}
-
-void
-MbXmlParser::MbXmlParserPrivate::addRating(XMLNode node, Entity *entity)
-{
-	entity->setRating(getFloat(node));
-	entity->setRatingVoteCount(getIntAttr(node, "votes-count"));
-}
-
-void
-MbXmlParser::MbXmlParserPrivate::addLabelAliasesToList(XMLNode listNode, LabelAliasList &resultList)
-{
-	addToList<LabelAlias, LabelAliasList>(listNode, resultList, &MbXmlParserPrivate::createLabelAlias);
-}
-
 MbXmlParser::MbXmlParser(/*IFactory &factory*/)
 {
 	d = new MbXmlParserPrivate();
@@ -679,18 +487,9 @@ MbXmlParser::parse(const std::string &data)
 			else if (name == string("release")) {
 				md->setRelease(d->createRelease(node));
 			}
-			else if (name == string("release-group")) {
-				md->setReleaseGroup(d->createReleaseGroup(node));
-			}
-			else if (name == string("label")) {
-				md->setLabel(d->createLabel(node));
-			}
 			else if (name == string("artist-list")) {
 				d->addArtistResults(node, md->getArtistResults());
 			}
-			else if (name == string("label-list")) {
-				d->addLabelResults(node, md->getLabelResults());
-			}
 			else if (name == string("track-list")) {
 				d->addTrackResults(node, md->getTrackResults());
 			}
